@@ -10,17 +10,14 @@
 #define __KCHATBASEMODEL_H__
 
 // own
-#include "libkdegamesprivate_export.h"
+#include "kdegamesprivate_export.h"
 // Qt
 #include <QAbstractListModel>
-#include <QLoggingCategory>
 #include <QPair>
 #include <QSharedDataPointer>
 // Std
 #include <memory>
 
-Q_DECLARE_LOGGING_CATEGORY(GAMES_LIB)
-
 class KChatBaseModelPrivate;
 class KChatBaseMessagePrivate;
 class KConfig;
